@@ -320,7 +320,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -511,8 +511,8 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
 
         Args:
             request (Union[google.cloud.clouddms_v1.types.ListMigrationJobsRequest, dict]):
-                The request object. Retrieve a list of all migration
-                jobs in a given project and location.
+                The request object. Retrieve a list of all migration jobs
+                in a given project and location.
             parent (str):
                 Required. The parent, which owns this
                 collection of migrationJobs.
@@ -625,8 +625,8 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
 
         Args:
             request (Union[google.cloud.clouddms_v1.types.GetMigrationJobRequest, dict]):
-                The request object. Request message for
-                'GetMigrationJob' request.
+                The request object. Request message for 'GetMigrationJob'
+                request.
             name (str):
                 Required. Name of the migration job
                 resource to get.
@@ -744,8 +744,8 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         Args:
             request (Union[google.cloud.clouddms_v1.types.CreateMigrationJobRequest, dict]):
                 The request object. Request message to create a new
-                Database Migration Service migration job in the
-                specified project and region.
+                Database Migration Service migration job
+                in the specified project and region.
             parent (str):
                 Required. The parent, which owns this
                 collection of migration jobs.
@@ -2405,7 +2405,7 @@ class DataMigrationServiceClient(metaclass=DataMigrationServiceClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "DataMigrationServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
